Introduction
============

This package contains various visual components for Plone, such as viewlets
and general views.

Since version 2.3.2 and up, this product only works on Plone 4.3 or higher.

If you are using Plone < 4.3.5 and you are using dexterity items and plone.app.contenttypes, you might want to pin the latest 2.3.x version of this package.
